+++
title = "Title with lots and lots / / / of forward/slashes"
tags = ["title"]
draft = false
+++

-   All forward slash characters meant for Org `/italic/` markup are
    removed.
-   The rest of the forward slash characters are retained.
